Author: Mindfactory.de
Description: Bei Mindfactory.de finden Sie günstige Hardware, Software, Notebooks, Computer, Digitalkameras, PDAs, Komplettsysteme und vieles mehr.
Keywords: Hardware, Notebook, Software, Mainboard, CPU, Festplatte, Grafikkarte

- +++ Hotline: Bitte nutzen Sie unseren Call-Back Service, wenn Sie nicht in Kürze weitergeleitet werden! +++
- +++ Aktionen, Hersteller und neue Produkte... Hier gibt es immer die aktuellsten News! +++
- +++ Cash-Backs, Gratis Zugaben & Co. - Informieren Sie sich jetzt in unseren Herstelleraktionen! +++

# Hardware, Notebooks & Software von Mindfactory.de

0 Artikel € 0,00
Merkzettel: 0
Login
info@mindfactory.de
04421 / 91 31 010
Wir rufen Sie auch zurück >

- Hardware
  - - Arbeitsspeicher (RAM)
    - Controller
    - Drucker
    - Eingabegeräte
    - Festplatten (HDD)
    - Gehäuse
    - Grafikkarten (VGA)
    - Kabel / Adapter
    - Kühlung Luft
    - Kühlung Wasser (WaKü)
    - Laufwerke / Medien
    - Mainboards
    - Monitore (TFT)
    - Netzteile / USVs (PSU)
    - Netzwerk (LAN / WLAN)
    - PC Reinigung
    - Prozessoren (CPU)
    - Scanner
    - Solid State Drives (SSD)
    - Sound
    - Speicherkarten
    - Speichersticks (USB Sticks)
    - TV- und Videokarten
    - Webcams
- Software
  - - Audioprogramme
    - Betriebssysteme
    - Brennprogramme
    - Grafik und Design
    - Kaufm. Anwendungen
    - Office
    - PC-Optimierung
    - Sicherheit
    - Sonstige
    - Sprach- und Lernprogramme
- Notebook | PC
  - - Netbooks
    - Notebooks
    - Zubehör für Notebook
    - Tablet PCs / eBooks
    - PC Systeme
    - Barebones
    - Server
- Kommunikation
  - - Anrufbeantworter
    - Festnetztelefone
    - IP Telefone
    - Mobiltelefone
    - Navigation
- Entertainment
  - - Beamer / Projektoren
    - Car HiFi
    - Digitale Bilderrahmen
    - DVD / Blu-ray Spieler
    - Fernbedienungen
    - Freizeit
    - Hi-Fi
    - Kameras
    - MP3 / Video Spieler
    - PC / Videospiele
    - Spielekonsolen
    - TV Geräte
    - TV Empfang
    - Zubehör für Entertainment
- Heim | Garten
  - - Batterien / Ladegeräte
    - Bürobedarf
    - Freizeit / Garten
    - Funkübertragung
    - Haushalt
    - Klima
    - Beauty / Gesundheit
    - Küchengeräte
    - Beleuchtung
    - Sicherheit
    - Uhren / Wecker
    - Weihnachtsdeko
    - Werkzeuge
- MindStar
- Gutscheine

### Anmeldung

E-Mail
Passwort

- Passwort vergessen?

Heute angemeldet bleiben?
Anmelden

- Zur Neuanmeldung

### Direkteinstieg

Bitte wählen Sie Ihre Zielseite:

### Meinungen & Zertifikate

9,3/10
10895 Kundenbewertungen für Mindfactory.de bei

Fair & transparent bestellen mit EHI.
Zum Zertifikat

### Sicher bezahlen per

Vorkasse

Sofortüberweisung

Paypal

FinanzierungTipp

Nachnahme

### Unsere Versandarten

UPS Express 24h

DHL-Versand

DHL Express 24h

sowie Selbstabholung

### Newsletter

Verpassen Sie nie wieder die neuesten Angebote! In unserem Newsletter finden Sie regelmäßig Angebote und Infos rund um unser Sortiment, Aktionen, Gewinnspiele und den Shop.
Los!

### Folgende Highlights warten auf Sie

MindStar
Tintenfinder
Midnight-Shopping
Herstelleraktionen
SchnäppShop
Weitere Highlights

### Unsere Empfehlungen für Sie

Artikel im Warenkorb

4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Re...

Zum Warenkorb

Artikel auf dem Merkzettel

4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Re...

Zum Merkzettel

#### 4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Retail)

http://www.mindfactory.de/basket_action/buy_now/4096MB-Inno3D-GeForce-GTX-970-iChill-X4-Air-Boss-Ultra-Aktiv-PCIe-3-0-x16--Retail-_978273.html#anchor_978273 http://www.mindfactory.de/wishlist_action/add/4096MB-Inno3D-GeForce-GTX-970-iChill-X4-Air-Boss-Ultra-Aktiv-PCIe-3-0-x16--Retail-_978273.html#anchor_978273
€ 369,90*
inkl. 19% USt + Versandkosten
über 140 verkauft
Artikel im Warenkorb

3072MB HIS Radeon R9 280 IceQ X2 OC Aktiv PCIe 3.0 x16 (Retail)

Zum Warenkorb

Artikel auf dem Merkzettel

3072MB HIS Radeon R9 280 IceQ X2 OC Aktiv PCIe 3.0 x16 (Retail)

Zum Merkzettel

#### 3072MB HIS Radeon R9 280 IceQ X2 OC Aktiv PCIe 3.0 x16 (Retail)

http://www.mindfactory.de/basket_action/buy_now/3072MB-HIS-Radeon-R9-280-IceQ-X2-OC-Aktiv-PCIe-3-0-x16--Retail-_964843.html#anchor_964843 http://www.mindfactory.de/wishlist_action/add/3072MB-HIS-Radeon-R9-280-IceQ-X2-OC-Aktiv-PCIe-3-0-x16--Retail-_964843.html#anchor_964843
Sonderpreis!
€ 178,78*
inkl. 19% USt + Versandkosten
über 260 verkauft
Artikel im Warenkorb

QNAP Turbo Station TS-212P 8 TB (2x 4000GB)

Zum Warenkorb

Artikel auf dem Merkzettel

QNAP Turbo Station TS-212P 8 TB (2x 4000GB)

Zum Merkzettel

#### QNAP Turbo Station TS-212P 8 TB (2x 4000GB)

http://www.mindfactory.de/basket_action/buy_now/QNAP-Turbo-Station-TS-212P-8-TB--2x-4000GB-_984401.html#anchor_984401 http://www.mindfactory.de/wishlist_action/add/QNAP-Turbo-Station-TS-212P-8-TB--2x-4000GB-_984401.html#anchor_984401
€ 465,90*
inkl. 19% USt + Versandkosten
No Sales Show
Artikel im Warenkorb

Cooltek Antiphon Black Midi Tower ohne Netzteil schwarz

Zum Warenkorb

Artikel auf dem Merkzettel

Cooltek Antiphon Black Midi Tower ohne Netzteil schwarz

Zum Merkzettel

#### Cooltek Antiphon Black Midi Tower ohne Netzteil schwarz

http://www.mindfactory.de/basket_action/buy_now/Cooltek-Antiphon-Black-Midi-Tower-ohne-Netzteil-schwarz_826905.html#anchor_826905 http://www.mindfactory.de/wishlist_action/add/Cooltek-Antiphon-Black-Midi-Tower-ohne-Netzteil-schwarz_826905.html#anchor_826905
Sonderpreis!
€ 61,47*
inkl. 19% USt + Versandkosten
über 2450 verkauft

Artikel im Warenkorb

4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

Zum Warenkorb

Artikel auf dem Merkzettel

4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

Zum Merkzettel

#### 4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

http://www.mindfactory.de/basket_action/buy_now/4096MB-Galax-GeForce-GTX-970-Black-Edition-Aktiv-PCIe-3-0-x16--Retail-_977718.html#anchor_977718 http://www.mindfactory.de/wishlist_action/add/4096MB-Galax-GeForce-GTX-970-Black-Edition-Aktiv-PCIe-3-0-x16--Retail-_977718.html#anchor_977718
€ 299,80*
inkl. 19% USt + Gratisversand
über 380 verkauft
Artikel im Warenkorb

550 Watt Corsair CS Series Modular 80+ Gold

Zum Warenkorb

Artikel auf dem Merkzettel

550 Watt Corsair CS Series Modular 80+ Gold

Zum Merkzettel

#### 550 Watt Corsair CS Series Modular 80+ Gold

http://www.mindfactory.de/basket_action/buy_now/550-Watt-Corsair-CS-Series-Modular-80--Gold_942715.html#anchor_942715 http://www.mindfactory.de/wishlist_action/add/550-Watt-Corsair-CS-Series-Modular-80--Gold_942715.html#anchor_942715
€ 80,47*
inkl. 19% USt + Versandkosten
über 1600 verkauft
Artikel im Warenkorb

120GB Samsung 840 Evo Series 2.5" (6.4cm) SATA 6Gb/s TLC Toggle (MZ-7TE1...

Zum Warenkorb

Artikel auf dem Merkzettel

120GB Samsung 840 Evo Series 2.5" (6.4cm) SATA 6Gb/s TLC Toggle (MZ-7TE1...

Zum Merkzettel

#### 120GB Samsung 840 Evo Series 2.5" (6.4cm) SATA 6Gb/s TLC Toggle (MZ-7TE120BW)

http://www.mindfactory.de/basket_action/buy_now/120GB-Samsung-840-Evo-Series-2-5Zoll--6-4cm--SATA-6Gb-s-TLC-Toggle--MZ-7TE120BW-_917097.html#anchor_917097 http://www.mindfactory.de/wishlist_action/add/120GB-Samsung-840-Evo-Series-2-5Zoll--6-4cm--SATA-6Gb-s-TLC-Toggle--MZ-7TE120BW-_917097.html#anchor_917097
€ 66,95*
inkl. 19% USt + Versandkosten
über 31300 verkauft
Artikel im Warenkorb

240GB SanDisk Ultra II 2.5" (6.4cm) SATA 6Gb/s MLC (SDSSDHII-240G-G25)

Zum Warenkorb

Artikel auf dem Merkzettel

240GB SanDisk Ultra II 2.5" (6.4cm) SATA 6Gb/s MLC (SDSSDHII-240G-G25)

Zum Merkzettel

#### 240GB SanDisk Ultra II 2.5" (6.4cm) SATA 6Gb/s MLC (SDSSDHII-240G-G25)

http://www.mindfactory.de/basket_action/buy_now/240GB-SanDisk-Ultra-II-2-5Zoll--6-4cm--SATA-6Gb-s-MLC--SDSSDHII-240G-G25-_974783.html#anchor_974783 http://www.mindfactory.de/wishlist_action/add/240GB-SanDisk-Ultra-II-2-5Zoll--6-4cm--SATA-6Gb-s-MLC--SDSSDHII-240G-G25-_974783.html#anchor_974783
€ 84,90*
inkl. 19% USt + Versandkosten
über 1410 verkauft

- Hardware
- Software
- Notebook | PC
- Kommunikation
- Entertainment
- Heim | Garten

- Artikel im Warenkorb

  530 Watt be quiet! Pure Power L8 CM Modular 80+ Bronze

  Zum Warenkorb

  Artikel auf dem Merkzettel

  530 Watt be quiet! Pure Power L8 CM Modular 80+ Bronze

  Zum Merkzettel

  #### 530 Watt be quiet! Pure Power L8 CM Modular 80+ Bronze

  http://www.mindfactory.de/basket_action/buynow/530-Watt-be-quiet--Pure-Power-L8-CM-Modular-80--Bronze_757838.html#anchor_757838 http://www.mindfactory.de/wishlist_action/add/530-Watt-be-quiet--Pure-Power-L8-CM-Modular-80--Bronze_757838.html#anchor_757838
  Sonderpreis!
  € 64,81*
  inkl. 19% USt + Versandkosten
  über 18430 verkauft
- Artikel im Warenkorb

  480 Watt be quiet! Straight Power E9 CM Modula 80+ Gold

  Zum Warenkorb

  Artikel auf dem Merkzettel

  480 Watt be quiet! Straight Power E9 CM Modula 80+ Gold

  Zum Merkzettel

  #### 480 Watt be quiet! Straight Power E9 CM Modula 80+ Gold

  http://www.mindfactory.de/basket_action/buynow/480-Watt-be-quiet--Straight-Power-E9-CM-Modula-80--Gold_768614.html#anchor_768614 http://www.mindfactory.de/wishlist_action/add/480-Watt-be-quiet--Straight-Power-E9-CM-Modula-80--Gold_768614.html#anchor_768614
  € 85,94*
  inkl. 19% USt + Versandkosten
  über 10520 verkauft
- Artikel im Warenkorb

  be quiet! Dark Rock Advanced C1 Tower Kühler

  Zum Warenkorb

  Artikel auf dem Merkzettel

  be quiet! Dark Rock Advanced C1 Tower Kühler

  Zum Merkzettel

  #### be quiet! Dark Rock Advanced C1 Tower Kühler

  http://www.mindfactory.de/basket_action/buynow/be-quiet--Dark-Rock-Advanced-C1-Tower-Kuehler_688967.html#anchor_688967 http://www.mindfactory.de/wishlist_action/add/be-quiet--Dark-Rock-Advanced-C1-Tower-Kuehler_688967.html#anchor_688967
  € 45,35*
  inkl. 19% USt + Versandkosten
  über 4310 verkauft
- Artikel im Warenkorb

  be quiet! Silent Wings 2 120x120x25mm 1500 U/min 16 dB(A) schwarz

  Zum Warenkorb

  Artikel auf dem Merkzettel

  be quiet! Silent Wings 2 120x120x25mm 1500 U/min 16 dB(A) schwarz

  Zum Merkzettel

  #### be quiet! Silent Wings 2 120x120x25mm 1500 U/min 16 dB(A) schwarz

  http://www.mindfactory.de/basket_action/buynow/be-quiet--Silent-Wings-2-120x120x25mm-1500-U-min-16-dB-A--schwarz_767381.html#anchor_767381 http://www.mindfactory.de/wishlist_action/add/be-quiet--Silent-Wings-2-120x120x25mm-1500-U-min-16-dB-A--schwarz_767381.html#anchor_767381
  € 15,79*
  inkl. 19% USt + Versandkosten
  über 6090 verkauft
- Artikel im Warenkorb

  be quiet! Silent Wings 2 140x140x25mm 1000 U/min 15.8 dB(A) schwarz

  Zum Warenkorb

  Artikel auf dem Merkzettel

  be quiet! Silent Wings 2 140x140x25mm 1000 U/min 15.8 dB(A) schwarz

  Zum Merkzettel

  #### be quiet! Silent Wings 2 140x140x25mm 1000 U/min 15.8 dB(A) schwarz

  http://www.mindfactory.de/basket_action/buynow/be-quiet--Silent-Wings-2-140x140x25mm-1000-U-min-15-8-dB-A--schwarz_767382.html#anchor_767382 http://www.mindfactory.de/wishlist_action/add/be-quiet--Silent-Wings-2-140x140x25mm-1000-U-min-15-8-dB-A--schwarz_767382.html#anchor_767382
  € 16,81*
  inkl. 19% USt + Versandkosten
  über 5190 verkauft
- Artikel im Warenkorb

  600 Watt Corsair CX Series Non-Modular 80+ Bronze

  Zum Warenkorb

  Artikel auf dem Merkzettel

  600 Watt Corsair CX Series Non-Modular 80+ Bronze

  Zum Merkzettel

  #### 600 Watt Corsair CX Series Non-Modular 80+ Bronze

  http://www.mindfactory.de/basket_action/buynow/600-Watt-Corsair-CX-Series-Non-Modular-80--Bronze_814860.html#anchor_814860 http://www.mindfactory.de/wishlist_action/add/600-Watt-Corsair-CX-Series-Non-Modular-80--Bronze_814860.html#anchor_814860
  € 59,90*
  inkl. 19% USt + Versandkosten
  über 1360 verkauft
- Artikel im Warenkorb

  430 Watt Corsair CX Series Non-Modular 80+ Bronze

  Zum Warenkorb

  Artikel auf dem Merkzettel

  430 Watt Corsair CX Series Non-Modular 80+ Bronze

  Zum Merkzettel

  #### 430 Watt Corsair CX Series Non-Modular 80+ Bronze

  http://www.mindfactory.de/basket_action/buynow/430-Watt-Corsair-CX-Series-Non-Modular-80--Bronze_816123.html#anchor_816123 http://www.mindfactory.de/wishlist_action/add/430-Watt-Corsair-CX-Series-Non-Modular-80--Bronze_816123.html#anchor_816123
  € 39,85*
  inkl. 19% USt + Versandkosten
  über 1370 verkauft
- Artikel im Warenkorb

  4096MB MSI GeForce GTX 970 Gaming 4G Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB MSI GeForce GTX 970 Gaming 4G Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB MSI GeForce GTX 970 Gaming 4G Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-MSI-GeForce-GTX-970-Gaming-4G-Aktiv-PCIe-3-0-x16--Retail-_976948.html#anchor_976948 http://www.mindfactory.de/wishlist_action/add/4096MB-MSI-GeForce-GTX-970-Gaming-4G-Aktiv-PCIe-3-0-x16--Retail-_976948.html#anchor_976948
  € 358,93*
  inkl. 19% USt + Gratisversand
  über 3170 verkauft
- Artikel im Warenkorb

  8GB Crucial Ballistix Sport DDR3-1600 DIMM CL9 Dual Kit

  Zum Warenkorb

  Artikel auf dem Merkzettel

  8GB Crucial Ballistix Sport DDR3-1600 DIMM CL9 Dual Kit

  Zum Merkzettel

  #### 8GB Crucial Ballistix Sport DDR3-1600 DIMM CL9 Dual Kit

  http://www.mindfactory.de/basket_action/buynow/8GB-Crucial-Ballistix-Sport-DDR3-1600-DIMM-CL9-Dual-Kit_794504.html#anchor_794504 http://www.mindfactory.de/wishlist_action/add/8GB-Crucial-Ballistix-Sport-DDR3-1600-DIMM-CL9-Dual-Kit_794504.html#anchor_794504
  Sonderpreis!
  € 62,38*
  inkl. 19% USt + Versandkosten
  über 41880 verkauft
- Artikel im Warenkorb

  4096MB Gigabyte GeForce GTX 970 Gaming G1 Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Gigabyte GeForce GTX 970 Gaming G1 Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Gigabyte GeForce GTX 970 Gaming G1 Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Gigabyte-GeForce-GTX-970-Gaming-G1-Aktiv-PCIe-3-0-x16--Retail-_976945.html#anchor_976945 http://www.mindfactory.de/wishlist_action/add/4096MB-Gigabyte-GeForce-GTX-970-Gaming-G1-Aktiv-PCIe-3-0-x16--Retail-_976945.html#anchor_976945
  Sonderpreis!
  € 346,60*
  inkl. 19% USt + Gratisversand
  über 1760 verkauft
- Artikel im Warenkorb

  1000GB Seagate Desktop HDD ST1000DM003 64MB 3.5" (8.9cm) SATA 6Gb/s

  Zum Warenkorb

  Artikel auf dem Merkzettel

  1000GB Seagate Desktop HDD ST1000DM003 64MB 3.5" (8.9cm) SATA 6Gb/s

  Zum Merkzettel

  #### 1000GB Seagate Desktop HDD ST1000DM003 64MB 3.5" (8.9cm) SATA 6Gb/s

  http://www.mindfactory.de/basket_action/buynow/1000GB-Seagate-Desktop-HDD-ST1000DM003-64MB-3-5Zoll--8-9cm--SATA-6Gb-s_775365.html#anchor_775365 http://www.mindfactory.de/wishlist_action/add/1000GB-Seagate-Desktop-HDD-ST1000DM003-64MB-3-5Zoll--8-9cm--SATA-6Gb-s_775365.html#anchor_775365
  € 46,36*
  inkl. 19% USt + Versandkosten
  über 59350 verkauft
- Artikel im Warenkorb

  Intel Xeon E3-1231v3 4x 3.40GHz So.1150 BOX

  Zum Warenkorb

  Artikel auf dem Merkzettel

  Intel Xeon E3-1231v3 4x 3.40GHz So.1150 BOX

  Zum Merkzettel

  #### Intel Xeon E3-1231v3 4x 3.40GHz So.1150 BOX

  http://www.mindfactory.de/basket_action/buynow/Intel-Xeon-E3-1231v3-4x-3-40GHz-So-1150-BOX_960054.html#anchor_960054 http://www.mindfactory.de/wishlist_action/add/Intel-Xeon-E3-1231v3-4x-3-40GHz-So-1150-BOX_960054.html#anchor_960054
  € 229,08*
  inkl. 19% USt + Versandkosten
  über 8080 verkauft
- Artikel im Warenkorb

  Intel Core i7 4790K 4x 4.00GHz So.1150 BOX

  Zum Warenkorb

  Artikel auf dem Merkzettel

  Intel Core i7 4790K 4x 4.00GHz So.1150 BOX

  Zum Merkzettel

  #### Intel Core i7 4790K 4x 4.00GHz So.1150 BOX

  http://www.mindfactory.de/basket_action/buynow/Intel-Core-i7-4790K-4x-4-00GHz-So-1150-BOX_962955.html#anchor_962955 http://www.mindfactory.de/wishlist_action/add/Intel-Core-i7-4790K-4x-4-00GHz-So-1150-BOX_962955.html#anchor_962955
  € 368,50*
  inkl. 19% USt + Versandkosten
  über 9330 verkauft
- Artikel im Warenkorb

  4096MB Palit GeForce GTX 970 JetStream Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Palit GeForce GTX 970 JetStream Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Palit GeForce GTX 970 JetStream Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Palit-GeForce-GTX-970-JetStream-Aktiv-PCIe-3-0-x16--Retail-_977473.html#anchor_977473 http://www.mindfactory.de/wishlist_action/add/4096MB-Palit-GeForce-GTX-970-JetStream-Aktiv-PCIe-3-0-x16--Retail-_977473.html#anchor_977473
  € 319,59*
  inkl. 19% USt + Gratisversand
  über 2680 verkauft
- Artikel im Warenkorb

  4096MB Gainward GeForce GTX 970 Phantom Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Gainward GeForce GTX 970 Phantom Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Gainward GeForce GTX 970 Phantom Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Gainward-GeForce-GTX-970-Phantom-Aktiv-PCIe-3-0-x16--Retail-_976943.html#anchor_976943 http://www.mindfactory.de/wishlist_action/add/4096MB-Gainward-GeForce-GTX-970-Phantom-Aktiv-PCIe-3-0-x16--Retail-_976943.html#anchor_976943
  € 323,02*
  inkl. 19% USt + Versandkosten
  über 1150 verkauft
- Artikel im Warenkorb

  4096MB Gigabyte GeForce GTX 970 Windforce 3X OC Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Gigabyte GeForce GTX 970 Windforce 3X OC Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Gigabyte GeForce GTX 970 Windforce 3X OC Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Gigabyte-GeForce-GTX-970-Windforce-3X-OC-Aktiv-PCIe-3-0-x16--Retail-_978515.html#anchor_978515 http://www.mindfactory.de/wishlist_action/add/4096MB-Gigabyte-GeForce-GTX-970-Windforce-3X-OC-Aktiv-PCIe-3-0-x16--Retail-_978515.html#anchor_978515
  € 326,77*
  inkl. 19% USt + Versandkosten
  über 1560 verkauft
- Artikel im Warenkorb

  4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Galax GeForce GTX 970 Black Edition Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Galax-GeForce-GTX-970-Black-Edition-Aktiv-PCIe-3-0-x16--Retail-_977718.html#anchor_977718 http://www.mindfactory.de/wishlist_action/add/4096MB-Galax-GeForce-GTX-970-Black-Edition-Aktiv-PCIe-3-0-x16--Retail-_977718.html#anchor_977718
  € 299,80*
  inkl. 19% USt + Gratisversand
  über 380 verkauft
- Artikel im Warenkorb

  4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Re...

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Re...

  Zum Merkzettel

  #### 4096MB Inno3D GeForce GTX 970 iChill X4 Air Boss Ultra Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Inno3D-GeForce-GTX-970-iChill-X4-Air-Boss-Ultra-Aktiv-PCIe-3-0-x16--Retail-_978273.html#anchor_978273 http://www.mindfactory.de/wishlist_action/add/4096MB-Inno3D-GeForce-GTX-970-iChill-X4-Air-Boss-Ultra-Aktiv-PCIe-3-0-x16--Retail-_978273.html#anchor_978273
  € 369,90*
  inkl. 19% USt + Versandkosten
  über 140 verkauft
- Artikel im Warenkorb

  4096MB Asus GeForce GTX 970 STRIX OC Edition Aktiv PCIe 3.0 x16 (Retail)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  4096MB Asus GeForce GTX 970 STRIX OC Edition Aktiv PCIe 3.0 x16 (Retail)

  Zum Merkzettel

  #### 4096MB Asus GeForce GTX 970 STRIX OC Edition Aktiv PCIe 3.0 x16 (Retail)

  http://www.mindfactory.de/basket_action/buynow/4096MB-Asus-GeForce-GTX-970-STRIX-OC-Edition-Aktiv-PCIe-3-0-x16--Retail-_976941.html#anchor_976941 http://www.mindfactory.de/wishlist_action/add/4096MB-Asus-GeForce-GTX-970-STRIX-OC-Edition-Aktiv-PCIe-3-0-x16--Retail-_976941.html#anchor_976941
  € 434,02*
  inkl. 19% USt + Versandkosten
  über 1470 verkauft
- Artikel im Warenkorb

  256GB Crucial MX100 2.5" (6.4cm) SATA 6Gb/s MLC (CT256MX100SSD1)

  Zum Warenkorb

  Artikel auf dem Merkzettel

  256GB Crucial MX100 2.5" (6.4cm) SATA 6Gb/s MLC (CT256MX100SSD1)

  Zum Merkzettel

  #### 256GB Crucial MX100 2.5" (6.4cm) SATA 6Gb/s MLC (CT256MX100SSD1)

  http://www.mindfactory.de/basket_action/buynow/256GB-Crucial-MX100-2-5Zoll--6-4cm--SATA-6Gb-s-MLC--CT256MX100SSD1-_964957.html#anchor_964957 http://www.mindfactory.de/wishlist_action/add/256GB-Crucial-MX100-2-5Zoll--6-4cm--SATA-6Gb-s-MLC--CT256MX100SSD1-_964957.html#anchor_964957
  € 92,73*
  inkl. 19% USt + Versandkosten
  über 10330 verkauft

## Hardware online kaufen bei mindfactory.de

Erleben Sie auf Mindfactory AG ein pures Shoppingerlebnis, denn bei uns können Sie aus einer riesigen Produktpalette von 100.000 Artikeln die für Sie am besten geeigneten Produkte auswählen! Ob Sie einzelne Komponenten aus dem Segment Hardware oder Software suchen, um ein eigenes Komplettsystem zusammen zu stellen, oder fertige PCs & Notebooks suchen, die Mindfactory AG bietet für jeden Anspruch das passende Gegenstück! Erhöhen Sie Ihre Lebensqualität mit Produkten aus unserer Kategorie Entertainment, in der für jeden LifeStyle die passenden LCD-TVs, BluRay-Player, Soundanlagen und viele anderen Produkte der Unterhaltungselektronik zu finden sind. Sie möchten immer mit Ihrem Umfeld in Kontakt bleiben und jederzeit erreichbar sein? Dann schauen Sie in unserem Bereich Kommunikation vorbei - ob Smartphones mit sozialen Netzwerkanbindungen direkt in der Hosentasche oder einfache Handys, für jeden ist das passende Gerät dabei. Auch für die ideale Freizeitgestaltung und die Ausstattung Ihres Zuhauses ist gesorgt: Bewährte Artikel und die neuesten Produkte auf dem Markt erwarten Sie in Haushalt. Begleiten Sie uns auf Facebook und Google+.

### Besuchen Sie auch unsere Partner:

Bitte bestellen Sie online - auch als Selbstabholer/in - ansonsten gelten im Mindfactory-Markt in Wilhelmshaven andere, höhere Preise.
1) Unser Ladengeschäft in Wilhelmshaven hat für Sie ab 10 Uhr geöffnet.
Alle Markennamen, Warenzeichen sowie sämtliche Produktbilder sind Eigentum ihrer rechtmäßigen Eigentümer und dienen hier nur der Beschreibung.
VPE-Angaben beziehen sich auf eine "Verpackungseinheit" OVP-Angaben beziehen sich auf "Originalverpackt"
* Alle hier genannten Preise verstehen sich inkl. 19% USt und zzgl. der Versandkosten in Höhe von € 7,99* sowie der Kosten für das gewählte Zahlungsmittel, 0,9% vom Warenwert bei Sofortüberweisung, 1,7% vom Warenwert bei PayPal, € 4,90* bei Nachnahme, € 0,00* Finanzierung (außer bei Fracht- und Express-Versand; bei Zahlung per Nachnahme entstehen weitere, an DHL zu zahlende Gebühren in Höhe von € 2,- inkl. 19% USt). Alle hier genannten Kosten verstehen sich inkl. 19% USt.
Bestellen Sie versandkostenfrei. Genauere Infos finden Sie hier.
© 2014 by Mindfactory AG